@@ -8,10 +8,11 @@ use Data::Dump qw( dump );
 use DBI;
 use SWISH::Prog::Utils;
 
-__PACKAGE__->mk_accessors(qw( db title alias_columns schema ));
+__PACKAGE__->mk_accessors(qw( db alias_columns schema ));
 
-our $VERSION = '0.26';
-our $XMLer   = $SWISH::Prog::Utils::XML;
+our $VERSION = '0.27';
+
+my $XMLer = Search::Tools::XML->new(); # included in Utils
 
 =pod
 
@@ -46,8 +47,8 @@ SWISH::Prog::Aggregator::DBI - index DB records with Swish-e
                swishtitle       => 'title',
           }
         }
-        alias_columns => 1,
-        indexer => SWISH::Prog::Indexer::Native->new
+        alias_columns   => 1,
+        indexer         => SWISH::Prog::Indexer::Native->new,
     );
     
     $aggregator->crawl();
@@ -193,7 +194,7 @@ sub init {
             'swishdefault '
                 . join( ' ',
                 map { '_' . $_ . '_row' }
-                    sort keys %{ $self->{schema} } ),
+                sort keys %{ $self->{schema} } ),
             1    # always append
         );
     }
@@ -324,22 +325,53 @@ sub _row2xml {
 
 __END__
 
-=head1 SEE ALSO
-
-L<http://swish-e.org/docs/>
-
-SWISH::Prog, Search::Tools
-
-
 =head1 AUTHOR
 
 Peter Karman, E<lt>perl@peknet.comE<gt>
 
+=head1 BUGS
+
+Please report any bugs or feature requests to C<bug-swish-prog at rt.cpan.org>, or through
+the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=SWISH-Prog>.  
+I will be notified, and then you'll
+automatically be notified of progress on your bug as I make changes.
+
+=head1 SUPPORT
+
+You can find documentation for this module with the perldoc command.
+
+    perldoc SWISH::Prog
+
+
+You can also look for information at:
+
+=over 4
+
+=item * RT: CPAN's request tracker
+
+L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=SWISH-Prog>
+
+=item * AnnoCPAN: Annotated CPAN documentation
+
+L<http://annocpan.org/dist/SWISH-Prog>
+
+=item * CPAN Ratings
+
+L<http://cpanratings.perl.org/d/SWISH-Prog>
+
+=item * Search CPAN
+
+L<http://search.cpan.org/dist/SWISH-Prog/>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2008 by Peter Karman
+Copyright 2008-2009 by Peter Karman
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself. 
 
-=cut
+=head1 SEE ALSO
+
+L<http://swish-e.org/>
