@@ -7,7 +7,7 @@ use MIME::Types;
 use File::Basename;
 use Search::Tools::XML;
 
-our $VERSION = '0.26';
+our $VERSION = '0.27';
 
 =pod
 
@@ -34,10 +34,6 @@ shared by many classes in the SWISH::Prog project.
 
 Regular expression of common file type extensions.
 
-=item $XML
-
-Instance of Search::Tools::XML.
-
 =item %ParserTypes
 
 Hash of MIME types to their equivalent parser.
@@ -46,9 +42,8 @@ Hash of MIME types to their equivalent parser.
 
 =cut
 
-our $ExtRE = qr{(html|htm|xml|txt|pdf|ps|doc|ppt|xls|mp3)(\.gz)?}io;
-our $XML   = Search::Tools::XML->new;
-
+our $ExtRE
+    = qr{(html|htm|xml|txt|pdf|ps|doc|ppt|xls|mp3|css|ico|js|php)(\.gz)?}io;
 our %ParserTypes = (
 
     # mime                  parser type
@@ -62,8 +57,14 @@ our %ParserTypes = (
     'default'            => 'HTML*',
 );
 
-my %ext2mime = ();    # cache to avoid hitting MIME::Type each time
+# cache to avoid hitting MIME::Type each time
+my %ext2mime = ();
+
+# prime the cache with some typical defaults that MIME::Type won't match.
+$ext2mime{'php'} = 'text/html';
+
 my $mime_types = MIME::Types->new;
+my $XML        = Search::Tools::XML->new;
 
 =head1 METHODS
 
@@ -79,6 +80,9 @@ sub mime_type {
     my $self = shift;
     my $url  = shift or return;
     my $ext  = shift || ( $self->path_parts($url) )[2];
+    $ext ||= 'html';
+
+    #warn "$url => $ext";
     if ( !exists $ext2mime{$ext} ) {
 
         # cache the mime type as a string
@@ -124,7 +128,8 @@ sub perl_to_xml {
     }
 
     if ( !ref $perl ) {
-        return $XML->start_tag($root)
+        return
+              $XML->start_tag($root)
             . $XML->utf8_safe($perl)
             . $XML->end_tag($root);
     }
@@ -204,11 +209,49 @@ __END__
 
 Peter Karman, E<lt>perl@peknet.comE<gt>
 
+=head1 BUGS
+
+Please report any bugs or feature requests to C<bug-swish-prog at rt.cpan.org>, or through
+the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=SWISH-Prog>.  
+I will be notified, and then you'll
+automatically be notified of progress on your bug as I make changes.
+
+=head1 SUPPORT
+
+You can find documentation for this module with the perldoc command.
+
+    perldoc SWISH::Prog
+
+
+You can also look for information at:
+
+=over 4
+
+=item * RT: CPAN's request tracker
+
+L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=SWISH-Prog>
+
+=item * AnnoCPAN: Annotated CPAN documentation
+
+L<http://annocpan.org/dist/SWISH-Prog>
+
+=item * CPAN Ratings
+
+L<http://cpanratings.perl.org/d/SWISH-Prog>
+
+=item * Search CPAN
+
+L<http://search.cpan.org/dist/SWISH-Prog/>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2008 by Peter Karman
+Copyright 2008-2009 by Peter Karman
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself. 
 
-=cut
+=head1 SEE ALSO
+
+L<http://swish-e.org/>
